package com.phm.manage.mapper;

import com.phm.manage.domain.Aeroplane;

import java.util.List;

/**
 * 单机信息Mapper接口
 *
 * @author phm
 * @date 2023-08-22
 */
public interface AeroplaneMapper {
    /**
     * 查询单机信息
     *
     * @param id 单机信息主键
     * @return 单机信息
     */
    public Aeroplane selectAeroplaneById(Long id);

    /**
     * 查询单机信息列表
     *
     * @param aeroplane 单机信息
     * @return 单机信息集合
     */
    public List<Aeroplane> selectAeroplaneList(Aeroplane aeroplane);

    /**
     * 新增单机信息
     *
     * @param aeroplane 单机信息
     * @return 结果
     */
    public int insertAeroplane(Aeroplane aeroplane);

    /**
     * 修改单机信息
     *
     * @param aeroplane 单机信息
     * @return 结果
     */
    public int updateAeroplane(Aeroplane aeroplane);

    /**
     * 删除单机信息
     *
     * @param id 单机信息主键
     * @return 结果
     */
    public int deleteAeroplaneById(Long id);

    /**
     * 批量删除单机信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAeroplaneByIds(Long[] ids);
}
